@@ -13,11 +13,11 @@ class Framework_MockObject_GeneratorTest extends PHPUnit_Framework_TestCase
 
     /**
      * @covers PHPUnit_Framework_MockObject_Generator::getMock
-     * @expectedException PHPUnit_Framework_Exception
+     * @expectedException PHPUnit_Framework_MockObject_RuntimeException
      */
     public function testGetMockFailsWhenInvalidFunctionNameIsPassedInAsAFunctionToMock()
     {
-        $this->generator->getMock(StdClass::class, [0]);
+        $this->generator->getMock(stdClass::class, [0]);
     }
 
     /**
@@ -25,7 +25,7 @@ class Framework_MockObject_GeneratorTest extends PHPUnit_Framework_TestCase
      */
     public function testGetMockCanCreateNonExistingFunctions()
     {
-        $mock = $this->generator->getMock(StdClass::class, ['testFunction']);
+        $mock = $this->generator->getMock(stdClass::class, ['testFunction']);
 
         $this->assertTrue(method_exists($mock, 'testFunction'));
     }
@@ -33,11 +33,11 @@ class Framework_MockObject_GeneratorTest extends PHPUnit_Framework_TestCase
     /**
      * @covers PHPUnit_Framework_MockObject_Generator::getMock
      * @expectedException PHPUnit_Framework_MockObject_RuntimeException
-     * @expectedExceptionMessage duplicates: "foo, foo"
+     * @expectedExceptionMessage duplicates: "foo, bar, foo" (duplicate: "foo")
      */
     public function testGetMockGeneratorFails()
     {
-        $this->generator->getMock(StdClass::class, ['foo', 'foo']);
+        $this->generator->getMock(stdClass::class, ['foo', 'bar', 'foo']);
     }
 
     /**
@@ -130,7 +130,7 @@ class Framework_MockObject_GeneratorTest extends PHPUnit_Framework_TestCase
     {
         return [
             'className not a string'     => [[], ''],
-            'mockClassName not a string' => [Countable::class, new StdClass],
+            'mockClassName not a string' => [Countable::class, new stdClass],
         ];
     }
 
@@ -178,6 +178,6 @@ class Framework_MockObject_GeneratorTest extends PHPUnit_Framework_TestCase
      */
     public function testExceptionIsRaisedForMutuallyExclusiveOptions()
     {
-        $this->generator->getMock(StdClass::class, [], [], '', false, true, true, true, true);
+        $this->generator->getMock(stdClass::class, [], [], '', false, true, true, true, true);
     }
 }
