@@ -1017,4 +1017,20 @@ class Framework_MockObjectTest extends PHPUnit_Framework_TestCase
           [['\Iterator','\Traversable']]
         ];
     }
+
+    public function testParameterCallbackConstraintOnlyEvaluatedOnce()
+    {
+        $mock                  = $this->getMockBuilder(Foo::class)->setMethods(['bar'])->getMock();
+        $expectedNumberOfCalls = 1;
+        $callCount             = 0;
+
+        $mock->expects($this->exactly($expectedNumberOfCalls))->method('bar')
+            ->with($this->callback(function ($argument) use (&$callCount) {
+                return $argument === 'call_' . $callCount++;
+            }));
+
+        for ($i = 0; $i < $expectedNumberOfCalls; $i++) {
+            $mock->bar('call_' . $i);
+        }
+    }
 }
